`ErrorPredClass` <-
function(Train, Test, Cl.Train, Cl.Test, Reg=plsr, ncomp=5){ 
#
# It finds the adjusted cross validation error rate (as done in package pls)
# for given training set and regression method.
#
# Train       : Training sample
# Test        : Test sample
# Cl.Train    : Class in training data. Classes are given as -1 or 1.
# Cl.Test     : Class in test data. Classes are given as -1 or 1.
# Reg        : Method of regression, which can be plsr or pcr
# ncomp      : Number of components taken in the pls/pc regression.
#              Eg., ncomp=5 means it will take components 1, 2, ..., 5.
#
    data.tr<-cbind(Train, y=Cl.Train)
    data.test<-cbind(Test, y=Cl.Test)
    dnames<-dimnames(data.tr)[[2]]
    data.test<-as.data.frame(data.test)
    dimnames(data.test)[[2]]<-dnames
    fit<-Reg(y~., ncomp,  data=data.tr)
#   Predicted responses for models with 1, 2,...,ncomp components
    pred.class.train<- predict(fit, ncomp=1:ncomp, newdata=data.tr)
    pred.class.test<- predict(fit, ncomp=1:ncomp, newdata=Test)
    pred.train<-ifelse(pred.class.train[,,]<0,-1,1)
    pred.test<-ifelse(pred.class.test[,,]<0,-1,1)
    ResultTrain<-sweep(pred.train, 1,Cl.Train)
    ResultTest<-sweep(pred.test, 1,Cl.Test)
    MisTrain<-apply(ResultTrain, 2, function(x)sum(x!=0))
    MisTest<-apply(ResultTest, 2, function(x)sum(x!=0))
    list(MisTrain, MisTest)
}

