`FitNNReg` <-
function(X,y,Xt,yt,Reg=plsr, ncomp=2, 
          number.NN=(nrow(X)-3), NN=seq(0,number.NN,5)){
#Assume X is design matrix form
stopifnot(is.matrix(X), is.matrix(Xt), is.vector(y), is.vector(yt))
X<-data.frame(X)
Xt<-data.frame(Xt)
            if (!all(sort(unique(y)) == c(-1, 1))) stop("y must be vector of 1 or -1's")
            if (!all(sort(unique(yt)) == c(-1, 1))) stop("yt must be vector of 1 or -1's")
            if (nrow(X) != length(y)) stop("nrow(X) != length(y)")
            if (nrow(Xt) != length(yt))  stop("nrow(Xt) != length(yt)")
            NRowTr<-nrow(X)
            NRowTest<-nrow(Xt)
            NColTr<-ncol(X)
            NN.max<-max(NN)
            KSeries<- OptimalK(1:number.NN,X, y)
            # If we want to use BIC to find the list of NN covariates then use the following.
      #     Z<-apply(matrix(1:number.NN,ncol=1),1,KNN.covariate.train,train=X, cl=y)
      #     KSeries<-OrderVar.glm(Z, y/2+0.5)
            ind<-matrix(KSeries[1:NN.max],ncol=1)
            Z.tr<-apply(ind,1,KNN.covariate.train, train=X, cl=y)
            Z.te<-apply(ind,1,KNN.covariate.test, train=X, cl=y, test= Xt)    
            Z.te<- matrix(Z.te,nrow=NRowTest)
            Z.te<-as.data.frame(Z.te)
            Z.tr<-as.data.frame(Z.tr)
            dimnames(Z.tr)[[2]]<-paste("X", (1:dim(Z.tr)[[2]]), sep="")
            dimnames(Z.te)[[2]]<-dimnames(Z.tr)[[2]] 
            # Use adjusted CV in leave-one-out method in the training data to find best
            # NN that minimizes error rate for each component. Then this the selected NN
            # for each component to find training error and test error.
            cv.NN <-function(mseq){
               if(mseq==0) trD<-X
                  else{trD<- cbind(X, Z.tr[,1:mseq])}
               NN.CV(trD, y, Reg=Reg, ncomp=ncomp)
            }
          # Different NN in columns and different number of comps in rows  
           cvAllComp<-apply(matrix(NN,ncol=1),1,cv.NN)
          
          Ind.Misclass<-apply(cvAllComp,1,which.min) # Find which NN minimizes the error. 
          SelectedNN<-NN[Ind.Misclass] # These are the the NN covariates for corresponding
                                       # PCR/PLSR components.  
          # We need to run get the prediction for each NN and so need the following function
           NNerror <-function(NNseq){
               if(NNseq==0){ trD<-X; teD<-Xt} else {
                   trD<- cbind(X, Z.tr[,1:NNseq]); teD<-cbind(Xt, Z.te[,1:NNseq])}
               ErrorPredClass(trD, teD, y, yt, Reg=Reg, ncomp=ncomp)
            }
          NN.comp<-apply(matrix(SelectedNN,ncol=1),1,NNerror)
          lNN<- length(SelectedNN)
          unlist.NN.comp<-unlist(NN.comp) 
          # We need to find two matrices of error rate, one for training sample and one for test set. 
          Index<-rep(1:2, each =ncomp,times=lNN)
          TrainError<-matrix(unlist.NN.comp[Index==1],byrow=TRUE,nrow=lNN)
          TestError<-matrix(unlist.NN.comp[Index==2],byrow=TRUE,nrow=lNN)
          TrainErrorRate<-diag(TrainError)/NRowTr
          TestErrorRate<-diag(TestError)/NRowTest
          ErrorRate<-as.data.frame(rbind(TrainErrorRate, TestErrorRate))
          dimnames(ErrorRate)[[1]]<-c("Train", "Test")
          dimnames(ErrorRate)[[2]]<-paste("Component",1:ncomp, sep="")        
          list(ErrorRate=ErrorRate, CVMatrix=cvAllComp) 
 }

