\name{Veer}
\alias{Veer}
\docType{data}
\title{ Breast cancer data set, Van't Veer et al., 2002}

\description{
Response is y=1 or y=-1 according as develop metastases or disease free.
There are 24188 gene expressions.

\tabular{rccc}{
Data	\tab y=1 \tab y=--1 \tab Total 	\cr
train	\tab 34 \tab 44 \tab 78 		\cr
test	\tab 3 \tab 5 \tab 8
}

Note: the gene expressions in BRAC1, BRAC2 and Sporadic are not identical.

}

\usage{data(Veer)}

\format{
List with 4 named elements, X, y, Xt, yt, which are respectively the
training design matrix, training classes, test design matrix and test classes.
}

\details{
78 primary breast cancers (34 from patients who developed distant metastases within 5 years and 44 from
patients who continue to be disease-free after a period of at least 5 years) have been selected from patients
who were lymph node negative and under 55 years of age at diagnosis. Two hybridizations were carried out for
each tumour using a fluorescent dye reversal technique on microarrays containing approximately 25000 human
genes synthesized by an inkjet oligonucleotide technology. The goal here is to predict the presence of subclinical
metastases in order to provide a strategy to select patients who would benefit from adjuvant therapy.
The training set consists of 78 breast cancer patients of which 34 develop metastases within 5 years and 44
remain disease-free within 5 years. The test set consists of 19 patients of which 12 develop metastases within
5 years and 7 remain disease-free within 5 years. The number of gene expression levels is 24188. This data
set contained some missing values. Gene expression levels lacking for all patients are left out. The rest of the
missing values is estimated based on the correlations between the gene expressions.
}

\source{
Nathalie Pochet, Frank De Smet, Johan A.K. Suykens and Bart L.R. De Moor (2004).
Systematic benchmarking of microarray data classification:
assessing the role of nonlinearity and dimensionality reduction.
Bioinformatics Advance Access published July 1, 2004.
\url{http://homes.esat.kuleuven.be/~npochet/Bioinformatics/}
}

\references{
Van't Veer,L.J., Dai,H., Van De Vijver,M.J., He,Y.D.,
Hart,A.A.M., Mao,M., Peterse,H.L., Van Der Kooy,K., Marton,
M.J., Witteveen,A.T., Schreiber,G.J., Kerkhoven,R.M.,
Roberts,C., Linsley,P.S., Bernards,R. and Friend,S.H.
(2002) Gene Expression Profiling Predicts Clinical Outcome
of Breast Cancer, Nature, 415,530-536.
}

\examples{
data(Veer)
OneDPlots(Veer$X, Veer$y)
}
\keyword{datasets}
